@@ -2,10 +2,12 @@ import click
 import getpass
 import pyhectiqlab
 import pyhectiqlab.ops as ops
+from pyhectiqlab.utils import load_event_manager
 from pyhectiqlab.auth import AuthProvider
 from pyhectiqlab.mlmodels import download_mlmodel as ops_download_mlmodel
 from pyhectiqlab.datasets import download_dataset as ops_download_dataset
 from pyhectiqlab.apps import download_app as ops_download_app
+from pyhectiqlab.apps import create_app as ops_create_app
 import socket
 
 @click.group()
@@ -91,3 +93,34 @@ def download_app(project, name, save_path, overwrite, raw):
 						no_dir=raw)
 	if dir_path is not None:
 		click.echo(f'App saved in {dir_path}')
+
+
+@cli.command()
+@click.option('-p', '--project', prompt="Project", help='Path of the project (e.g. `hectiqai/project`)', required=True)
+@click.option('-n', '--name', prompt='App name', help='Name of the app', required=True)
+@click.option('-d', '--description', prompt='App description', help='A one-line description of what the app does', required=False)
+@click.option('--files_path', prompt='Path to the folder containing the app', help='Path to the files',required=True)
+@click.option('--privacy', help='Privacy settings (public or private) ["private"]', type=click.Choice(['public', 'private']), required=True)
+@click.option('--app_type', prompt='The app type',  help='The app type', type=click.Choice(['streamlit', 'gradio', 'plotly']), required=True)
+def create_app(project, name, description, files_path, privacy, app_type):
+	manager = load_event_manager()
+	results = manager.add_event("fetch_instance_types", (project,), async_method=False)
+	if results.get("status_code")!=200:
+		click.echo(results.get("detail", "Something wrong occured."))
+		return
+	click.echo(results.get("payload")["msg"])
+	instance_types = results.get("results")
+	choices = click.Choice([r["name"] for r in instance_types], case_sensitive=True)
+	instances_description = "\n\n"
+	for r in instance_types:
+		instances_description += f"[{r['name']}] {r['points']} points\n  {r['description']}\n  {r['tip']}\n\n"
+
+	instance_type = click.prompt(f"Select your instance type: {instances_description}", type=choices, show_choices=True)
+
+	ops_create_app(name=name, 
+				project=project,
+				app_type=app_type, 
+				instance=instance_type, 
+				is_private=privacy=="private", 
+				dir_path=files_path, 
+				description=description)
