@@ -107,6 +107,12 @@ def fetch_run_logs(path, project_path, token):
                 token=token)
     return res
 
+def clear_logs(path, project_path, token):
+    res = lab_request(path=f"/{project_path}/runs/{path}/clear-logs", 
+                request_type="POST", 
+                token=token)
+    return res
+
 def fetch_run_configs(path, project_path, token):
     res = lab_request(path=f"/{project_path}/runs/{path}/configs", 
                 request_type="GET", 
@@ -190,6 +196,12 @@ def log_dataset(run_path, project_path, dataset_name, version, token):
                      query_args=dict(dataset_name=dataset_name, version=version))
     return res
 
+def fetch_instance_types(project_path, token):
+    res = lab_request(path=f"/{project_path}/available-cloud-instances?",
+                     request_type="GET",
+                     token=token)
+    return res
+
 def append_logs(run_path, project_path, logs, token):
     if logs is None:
         return
@@ -238,7 +250,7 @@ def get_dataset_download_info(dataset_name, project_path, version, page, token):
     res = lab_request(path=f"/{project_path}/datasets/{dataset_name}/download",
                      request_type="GET",
                      token=token,
-                     query_args=dict(version=version, page=page, limit=5))
+                     query_args=dict(version=version, page=page))
     return res
 
 def get_app_download_info(app_name, project_path, page, token):
@@ -303,6 +315,7 @@ def add_dataset(run_path,
                 name: str, 
                 short_description: str, 
                 version: str, 
+                resume_upload: bool,
                 token: str = None):
 
     # Create dataset
@@ -311,6 +324,7 @@ def add_dataset(run_path,
             filenames=[], 
             short_description=short_description, 
             num_bytes=[], 
+            resume_upload=resume_upload,
             version=version)
     res = lab_request(path=f"/{project_path}/datasets",
                          request_type="POST",
@@ -326,7 +340,7 @@ def add_dataset(run_path,
         batch_num_bytes = list(zip(*batch))[2]
 
         # Get policy
-        body = dict( filenames=batch_filenames, num_bytes=batch_num_bytes)
+        body = dict(filenames=batch_filenames, num_bytes=batch_num_bytes, resume_upload=resume_upload)
 
         res = lab_request(path=f"/app/datasets/{dataset_uuid}/add-files",
                          request_type="POST",
@@ -345,4 +359,38 @@ def get_all_projects(token):
     res = lab_request(path="/app/user/projects",
                      request_type="GET",
                      token=token)
-    return res
\ No newline at end of file
+    return res
+
+def create_app(name, project, description, instance, is_private, app_type, token):
+    res = lab_request(path=f"/{project}/apps",
+                     request_type="POST",
+                     body_args=dict(name=name, description=description, instance=instance, private=is_private, app_type=app_type),
+                     token=token)
+    return res
+
+def upload_app_files(name, 
+                project,
+                filenames: List[str], 
+                full_paths: List[str], 
+                num_bytes: List[int], 
+                resume_upload: bool,
+                token: str = None):
+    batch_size = 20 # Number of elements to send
+    for batch in chunked(zip(filenames, full_paths, num_bytes), batch_size):
+        batch_filenames = list(zip(*batch))[0]
+        batch_num_bytes = list(zip(*batch))[2]
+
+        # Get policy
+        body = dict(filenames=batch_filenames, num_bytes=batch_num_bytes, resume_upload=resume_upload)
+
+        res = lab_request(path=f"/{project}/apps/{name}/add-files",
+                         request_type="POST",
+                         token=token,
+                         body_args=body)
+        assert res.get('status_code') == 200, f"An error occured while pushing new files: {res.get('detail')}"
+
+        for policy, filename in zip(res['policies'], batch_filenames):
+            logger.info(f'Uploading {filename}')
+            upload_file(full_paths[filename], policy)
+
+
